@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-types
 version: 0.9
-id: http-types-0.9-d392878af9c5e1b1993961dc71a9e177
-key: httpt_3Bf1bEHnPYIAJ2rfQRlloD
+id: http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+key: httpt_2kqnYpPBpbH1f4ygoPM6qu
 license: BSD3
 copyright: (C) 2011 Aristid Breitkreuz
 maintainer: aristidb@googlemail.com
@@ -23,14 +23,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/http-types-0.9
 library-dirs: /usr/lib/ghc-7.10.3/site-local/http-types-0.9
 data-dir: /usr/share/arm-linux-ghc-7.10.3/http-types-0.9
-hs-libraries: HShttp-types-0.9-3Bf1bEHnPYIAJ2rfQRlloD
+hs-libraries: HShttp-types-0.9-2kqnYpPBpbH1f4ygoPM6qu
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
 haddock-html: /usr/share/doc/haskell-http-types/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
